@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2010 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2010 Volker Krause <vkrause@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-    USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "agentconfigmodel.h"
@@ -23,7 +10,8 @@
 #include <QMetaMethod>
 #include "akonadiconsole_debug.h"
 
-AgentConfigModel::AgentConfigModel(QObject *parent): QAbstractTableModel(parent), m_interface(nullptr)
+AgentConfigModel::AgentConfigModel(QObject *parent) : QAbstractTableModel(parent)
+    , m_interface(nullptr)
 {
 }
 
@@ -37,7 +25,6 @@ void AgentConfigModel::setAgentInstance(const Akonadi::AgentInstance &instance)
     beginResetModel();
     m_settings.clear();
 
-
     m_interface = new QDBusInterface(
         QStringLiteral("org.freedesktop.Akonadi.Agent.%1").arg(instance.identifier()),
         QStringLiteral("/Settings"));
@@ -153,4 +140,3 @@ void AgentConfigModel::writeConfig()
 {
     m_interface->call(QStringLiteral("save"));
 }
-
