@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2009 Stephen Kelly <steveire@gmail.com>
+    SPDX-FileCopyrightText: 2009 Stephen Kelly <steveire@gmail.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "akonadibrowsermodel.h"
@@ -27,17 +14,19 @@
 #include <KCalendarCore/Incidence>
 #include <KCalendarCore/Event>
 
-typedef QSharedPointer<KCalendarCore::Incidence> IncidencePtr;
+using IncidencePtr = QSharedPointer<KCalendarCore::Incidence>;
 
 class AkonadiBrowserModel::State
 {
 public:
-    virtual ~State() {}
+    virtual ~State()
+    {
+    }
+
     QStringList m_collectionHeaders;
     QStringList m_itemHeaders;
 
     virtual QVariant entityData(const Item &item, int column, int role) const = 0;
-
 };
 
 class GenericState : public AkonadiBrowserModel::State
@@ -48,6 +37,7 @@ public:
         m_collectionHeaders << QStringLiteral("Collection");
         m_itemHeaders << QStringLiteral("Id") << QStringLiteral("Remote Id") << QStringLiteral("GID") << QStringLiteral("MimeType");
     }
+
     virtual ~GenericState()
     {
     }
@@ -77,7 +67,6 @@ public:
         }
         return QVariant();
     }
-
 };
 
 class MailState : public AkonadiBrowserModel::State
@@ -88,7 +77,10 @@ public:
         m_collectionHeaders << QStringLiteral("Collection");
         m_itemHeaders << QStringLiteral("Subject") << QStringLiteral("Sender") << QStringLiteral("Date");
     }
-    virtual ~MailState() {}
+
+    virtual ~MailState()
+    {
+    }
 
     QVariant entityData(const Item &item, int column, int role) const override
     {
@@ -125,7 +117,6 @@ public:
 
         return QVariant();
     }
-
 };
 
 class ContactsState : public AkonadiBrowserModel::State
@@ -136,7 +127,10 @@ public:
         m_collectionHeaders << QStringLiteral("Collection");
         m_itemHeaders << QStringLiteral("Given Name") << QStringLiteral("Family Name") << QStringLiteral("Email");
     }
-    virtual ~ContactsState() {}
+
+    virtual ~ContactsState()
+    {
+    }
 
     QVariant entityData(const Item &item, int column, int role) const override
     {
@@ -162,7 +156,6 @@ public:
             return QVariant();
         }
         if (item.hasPayload<KContacts::ContactGroup>()) {
-
             switch (column) {
             case 0:
                 const KContacts::ContactGroup group = item.payload<KContacts::ContactGroup>();
@@ -182,7 +175,10 @@ public:
         m_collectionHeaders << QStringLiteral("Collection");
         m_itemHeaders << QStringLiteral("UID") << QStringLiteral("Summary") << QStringLiteral("DateTime start") << QStringLiteral("DateTime End") << QStringLiteral("Type");
     }
-    virtual ~CalendarState() {}
+
+    virtual ~CalendarState()
+    {
+    }
 
     QVariant entityData(const Item &item, int column, int role) const override
     {
@@ -214,10 +210,8 @@ public:
 };
 
 AkonadiBrowserModel::AkonadiBrowserModel(ChangeRecorder *monitor, QObject *parent)
-    : EntityTreeModel(monitor, parent),
-      m_itemDisplayMode(GenericMode)
+    : EntityTreeModel(monitor, parent)
 {
-
     m_genericState = new GenericState();
     m_mailState = new MailState();
     m_contactsState = new ContactsState();
