@@ -1,26 +1,13 @@
 /*
- * Copyright (C) 2014  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2014 Daniel Vrátil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
  */
 
 #include "tagpropertiesdialog.h"
 #include "dbaccess.h"
 
-
 #include <AkonadiCore/AttributeFactory>
 #include <QSqlQuery>
 #include <QDialogButtonBox>
@@ -30,7 +17,6 @@ using namespace Akonadi;
 
 TagPropertiesDialog::TagPropertiesDialog(QWidget *parent)
     : QDialog(parent)
-    , mChanged(false)
 {
     setupUi();
 }
@@ -59,16 +45,16 @@ bool TagPropertiesDialog::changed() const
 
 void TagPropertiesDialog::setupUi()
 {
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &TagPropertiesDialog::slotAccept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &TagPropertiesDialog::reject);
 
-    QWidget *widget = new QWidget(this);
+    auto *widget = new QWidget(this);
     ui.setupUi(widget);
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(widget);
     mainLayout->addWidget(buttonBox);
 
